summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libsvn/svnhandler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/libsvn/svnhandler.cpp')
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.cpp b/kbabel/catalogmanager/libsvn/svnhandler.cpp
index 71907fb8..5f91e1e8 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.cpp
+++ b/kbabel/catalogmanager/libsvn/svnhandler.cpp
@@ -274,18 +274,18 @@ TQString SVNHandler::svntqStatus( const TQString& filename ) const
return map[filename];
}
-void SVNHandler::execSVNCommand( TQWidget* tqparent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config)
+void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config)
{
// Unlike cvs, svn works also from outside the repository(as long as the path is in a repository of course!)
// ### FIXME: wrong, svn commit cannot work if the current directory is not a SVN one
- execSVNCommand( tqparent, cmd, TQStringList( filename ), templates, config );
+ execSVNCommand( parent, cmd, TQStringList( filename ), templates, config );
}
-void SVNHandler::execSVNCommand( TQWidget* tqparent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
+void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
{
if ( !_isPORepository ) {
// This message box should never be visible but who knows... ;-)
- KMessageBox::sorry( tqparent, i18n( "This is not a valid SVN repository. "
+ KMessageBox::sorry( parent, i18n( "This is not a valid SVN repository. "
"The SVN commands cannot be executed." ) );
return;
}
@@ -328,7 +328,7 @@ void SVNHandler::execSVNCommand( TQWidget* tqparent, SVN::Command cmd, const TQS
command += " \'" + temp + "\'";
}
- showDialog( tqparent, cmd, files, command, config );
+ showDialog( parent, cmd, files, command, config );
}
void SVNHandler::setAutoUpdateTemplates( bool update )
@@ -336,9 +336,9 @@ void SVNHandler::setAutoUpdateTemplates( bool update )
_autoUpdateTemplates = update;
}
-void SVNHandler::showDialog( TQWidget* tqparent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
+void SVNHandler::showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
{
- SVNDialog * dia = new SVNDialog( cmd, tqparent, config );
+ SVNDialog * dia = new SVNDialog( cmd, parent, config );
dia->setFiles( files );
dia->setCommandLine( commandLine );
if ( cmd == SVN::Commit ) {
@@ -415,7 +415,7 @@ void SVNHandler::checkToAdd( const TQStringList& files )
}
// ### TODO: does SVN really needs this or does it do it automatically?
// check recursivlely if tqparent dirs have to be added as well
while ( ! isInSvn( temp ) && toBeAdded.findIndex( temp ) == -1 ) {
toBeAdded << temp;
temp = TQFileInfo( temp ).dirPath( true );
@@ -415,7 +415,7 @@ void SVNHandler::checkToAdd( const TQStringList& files )
}
// ### TODO: does SVN really needs this or does it do it automatically?
- // check recursivlely if tqparent dirs have to be added as well
+ // check recursivlely if parent dirs have to be added as well
while ( ! isInSvn( temp ) && toBeAdded.findIndex( temp ) == -1 ) {
toBeAdded << temp;